import { __awaiter, __decorate } from "tslib";
import { Datasource } from '@genesislcap/foundation-comms';
import { formatDateTimestamp, formatDateTimeTimestamp } from '@genesislcap/foundation-utils';
import { customElement, FASTElement, observable, attr } from '@microsoft/fast-element';
import { getColumns, getGridOptions } from './columns';
import { PreviewStyles as styles } from './preview.styles';
import { PreviewReportTemplate as template } from './preview.template';
const name = 'reporting-preview';
let Preview = class Preview extends FASTElement {
    constructor() {
        super(...arguments);
        this.report = {};
        this.fetchAndLoadToGrid = () => __awaiter(this, void 0, void 0, function* () {
            const resourceName = this.report['REPORT_DATASOURCE'] || this.report['REPORT_DATA_SOURCE'];
            yield this.datasource.init(Object.assign({ resourceName }, this.datasourceSettings), true);
            this.data = yield this.datasource.snapshotFiltered();
            this.grid['gridOptions'] = Object.assign(Object.assign({}, getGridOptions()), { columnDefs: getColumns(this.report['REPORT_COLUMNS']), rowData: this.data });
        });
        this.exportToCsv = () => {
            const params = {
                fileName: 'export.csv',
            };
            params.processCellCallback = (cellParams) => this.formatDateType(cellParams);
            this.grid.gridApi.exportDataAsCsv(Object.assign({}, params));
        };
        this.formatDateType = (cellParams) => {
            let dateFormatter;
            this.report['REPORT_COLUMNS'].forEach((column) => {
                if (column.name == cellParams.column.colId) {
                    column.type === 'DATE'
                        ? (dateFormatter = formatDateTimestamp(cellParams.value))
                        : column.type === 'DATETIME'
                            ? (dateFormatter = formatDateTimeTimestamp(cellParams.value))
                            : (dateFormatter = cellParams.value);
                }
            });
            return dateFormatter;
        };
    }
    reportChanged(old, newValue) {
        if (old && Object.keys(old).length != 0 && Object.keys(newValue).length > 0) {
            this.fetchAndLoadToGrid();
        }
    }
    connectedCallback() {
        super.connectedCallback();
        this.fetchAndLoadToGrid();
        this.grid.addEventListener('onGridReady', () => {
            const model = {};
            this.report['REPORT_COLUMNS']
                .filter((f) => f.filter)
                .forEach((f) => {
                model[f.name] = {
                    filterType: 'text',
                    type: f.filter.conditional,
                    filter: f.filter.value,
                };
            });
            this.grid.gridApi.setFilterModel(model);
            window.addEventListener('resize', () => {
                setTimeout(() => {
                    this.grid.columnApi.autoSizeAllColumns();
                });
            });
            this.grid.gridApi.addEventListener('firstDataRendered', () => {
                this.grid.columnApi.autoSizeAllColumns();
            });
        });
    }
};
__decorate([
    Datasource
], Preview.prototype, "datasource", void 0);
__decorate([
    attr
], Preview.prototype, "report", void 0);
__decorate([
    observable
], Preview.prototype, "data", void 0);
__decorate([
    observable
], Preview.prototype, "datasourceSettings", void 0);
Preview = __decorate([
    customElement({
        name,
        template,
        styles,
    })
], Preview);
export { Preview };
